@@ -48,6 +48,10 @@ class Redmine(object):
 
         return response['upload']['token']
 
+    def auth(self):
+        """Shortcut for the case if we just want to check if user provided valid auth credentials"""
+        return self.user.get('current')
+
     def request(self, method, url, headers=None, params=None, data=None):
         """Makes requests to Redmine and returns result in json format"""
         kwargs = dict(self.requests, **{
@@ -72,7 +76,7 @@ class Redmine(object):
         response = getattr(requests, method)(url, **kwargs)
 
         if response.status_code in (200, 201):
-            if not response.content:
+            if not response.content.strip():
                 return True
             return response.json()
         elif response.status_code == 401:
